@@ -15,7 +15,7 @@ def main():
     parser.add_argument('--rl', help='arg2 help')
     args = parser.parse_args()
     print("remove_length {}, static_url {}".format(args.rl, args.su))
-    removeLength = args.rl if int(args.rl) else 9
+    removeLength = int(args.rl) if args.rl else 9
     staticUrl = args.su if args.su else 'static'
     loadStatic = "{% load static %}"
     cwd = os.getcwd()
